Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(288)

Unified Diff: webrtc/p2p/base/udptransport.h

Issue 2679103006: Rename "PacketTransportInterface" to "PacketTransportInternal". (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/transportcontroller.cc ('k') | webrtc/p2p/base/udptransport_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/udptransport.h
diff --git a/webrtc/p2p/base/udptransport.h b/webrtc/p2p/base/udptransport.h
index 126e9e2bf909f49e01afaf1a50c517320f9b8f48..e8bd49382f22958f588d165a81c791a438e4efbe 100644
--- a/webrtc/p2p/base/udptransport.h
+++ b/webrtc/p2p/base/udptransport.h
@@ -18,7 +18,7 @@
#include "webrtc/base/asyncpacketsocket.h" // For PacketOptions.
#include "webrtc/base/optional.h"
#include "webrtc/base/thread_checker.h"
-#include "webrtc/p2p/base/packettransportinterface.h"
+#include "webrtc/p2p/base/packettransportinternal.h"
namespace rtc {
class AsyncPacketSocket;
@@ -32,7 +32,7 @@ namespace cricket {
// Implementation of UdpTransportInterface.
// Used by OrtcFactory.
class UdpTransport : public webrtc::UdpTransportInterface,
- public rtc::PacketTransportInterface {
+ public rtc::PacketTransportInternal {
public:
// |transport_name| is only used for identification/logging.
// |socket| must be non-null.
@@ -45,7 +45,7 @@ class UdpTransport : public webrtc::UdpTransportInterface,
bool SetRemoteAddress(const rtc::SocketAddress& addr) override;
rtc::SocketAddress GetRemoteAddress() const override;
// Overrides of PacketTransportInterface, used by webrtc internally.
std::string debug_name() const override { return transport_name_; }
bool receiving() const override {
« no previous file with comments | « webrtc/p2p/base/transportcontroller.cc ('k') | webrtc/p2p/base/udptransport_unittest.cc » ('j') | no next file with comments »
@@ -45,7 +45,7 @@ class UdpTransport : public webrtc::UdpTransportInterface,
bool SetRemoteAddress(const rtc::SocketAddress& addr) override;
rtc::SocketAddress GetRemoteAddress() const override;
- // Overrides of PacketTransportInterface, used by webrtc internally.
+ // Overrides of PacketTransportInternal, used by webrtc internally.
std::string debug_name() const override { return transport_name_; }
bool receiving() const override {

Powered by Google App Engine
This is Rietveld 408576698